==> nextcloud-14.0.13.zip: nextcloud/apps/activity/l10n/mk.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Активност",
    "An error occurred while loading activities" : "Грешка при вчитување на активностите",
    "No activity yet" : "Сеуште нема активности",
    "Load more activities" : "Вчитај повеќе активности",
    "Copied!" : "Копирано!",
    "Not supported!" : "Не е поддржано!",
    "Press ⌘-C to copy." : "Притиснете ⌘-C за да копирате.",
    "Press Ctrl-C to copy." : "Притиснете Ctrl-C за да копирате.",
    "{name} (invisible)" : "{име} (невидливо)",
    "{name} (restricted)" : "{име} (ограчничено)",
    "Home" : "Дома",
    "in {path}" : "во {патека}",
    "This stream will show events like additions, changes & shares" : "Овој стрим ќе прикажува настани како додатоци, промени и споделувања",
    "There are no events for this filter" : "Нема настани за овој филтер",
    "Today" : "Денеска",
    "Yesterday" : "Вчера",
    "Open file" : "Отвори датотека",
    "Personal activity feed for %s" : "Feed на лични активности за %s",
    "Your feed URL is invalid" : "Вашиот URL за feed не е исправен",
    "Your settings have been updated." : "Вашите поставки беа ажурирани.",
    "Settings have been updated." : "Поставките се ажурирани.",
    "All activities" : "Сите активности",
    "By others" : "Од други",
    "By you" : "Од вас",
    "Activity notification for %s" : "Известување за активност за %s",
    "Hello %s" : "Здраво %s",
    "Hello %s," : "Здраво %s,",
    "There was some activity at %s" : "Имаше активност во %s",
    "Mail" : "Електронска пошта",
    "Stream" : "Стрим",
    "This application enables users to view actions related to their files in Nextcloud." : "Оваа апликација им овозможува на корисниците да ги прикажуваат активностите поврзани со нивните датотеки во Nextcloud.",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "Оваа апликација им овозможува на корисниците да ги проверат активностите поврзани со нивните датотеки во Nextcloud.\n\t\tОткако ќе биде овозможено, корисниците ќе видат нова икона „Активност” во менито за апликации.\n\t\tКога ќе се кликне на неа, се појавува нова страница за корисниците да ја следат активноста поврзана со датотеките - од нови датотеки, до избришани датотеки, преместување, преименување, надградби и споделена активност.\n\t\tКорисникот може да ги конфигурира неговите поединечни поставки за активност во неговото лично мени.\n\t\tОва ја поставува активноста за снимање, како и дали корисникот ги гледа своите активности,\n\t\tбез разлика дали тие се достапни само онлајн, односно дали тие се редовно сврзани како мејлови.\n\t\tПовеќе информации се достапни во документацијата за активноста.",
    "Activity feed" : "Feed на активности",
    "Send activity emails" : "Прати е-маил за активација",
    "Default settings" : "Стандардни поставки",
    "Configure the default activity settings for new users." : "Конфигурирајте ги стандардните поставки за активност за нови корисници.",
    "List your own actions in the stream" : "Наведете ги вашите сопствени акции во stream-от",
    "Notify about your own actions via email" : "Извести за своите активности преку порака",
    "You need to set up your email address before you can receive notification emails." : "Треба да ја внесете Вашата електронска адреса за да можете да примате известувања по електронска пошта.",
    "Send emails:" : "Прати пораки:",
    "As soon as possible" : "Што побрзо",
    "Hourly" : "Часовно",
    "Daily" : "Дневно",
    "Weekly" : "Неделно",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Изберете за кои активности сакате да добивате известување по е-пошта, а кои треба да се појавуваат во текот на апликацијата за активност.",
    "Choose which activities you want to see in your stream." : "Изберете кои активности сакате да ги видите во вашиот \"stream\".",
    "Settings" : "Нагодување",
    "Enable RSS feed" : "Овозможи RSS feed",
    "RSS feed" : "RSS feed",
    "No more events to load" : "Нема повеќе настани за вчитување",
    "Activities" : "Активности",
    "\"remote user\"" : "\"далечен корисник\"",
    ", " : ", ",
    "%s and %s" : "%s и %s",
    "Files" : "Датотеки"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-15.0.3.zip: nextcloud/apps/activity/l10n/mk.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Активност",
    "No activity yet" : "Сеуште нема активности",
    "This stream will show events like additions, changes & shares" : "Овој стрим ќе прикажува настани како додатоци, промени и споделувања",
    "There are no events for this filter" : "Нема настани за овој филтер",
    "Today" : "Денеска",
    "Yesterday" : "Вчера",
    "Personal activity feed for %s" : "Feed на лични активности за %s",
    "Your feed URL is invalid" : "Вашиот URL за feed не е исправен",
    "Your settings have been updated." : "Вашите нагодувања беа освежени.",
    "\"remote user\"" : "\"далечен корисник\"",
    "Hello %s," : "Здраво %s,",
    ", " : ", ",
    "%s and %s" : "%s и %s",
    "Mail" : "Електронска пошта",
    "Stream" : "Стрим",
    "Activity feed" : "Feed на активности",
    "Notify about your own actions via email" : "Извести за своите активности преку порака",
    "You need to set up your email address before you can receive notification emails." : "Треба да ја внесете Вашата електронска адреса за да можете да примате известувања по електронска пошта.",
    "Send emails:" : "Пратени пораки:",
    "Hourly" : "Часовно",
    "Daily" : "Дневно",
    "Weekly" : "Неделно",
    "Enable RSS feed" : "Овозможи RSS feed",
    "No more events to load" : "Нема повеќе настани да вчитам",
    "Files" : "Датотеки",
    "Activities" : "Активности",
    "Activity notification" : "Известување за Активности"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
